Coverage for airflow.operators.dummy_operator: 89%

# Coverage for airflow.operators.dummy_operator : 89%

## 9 statements 8 run 1 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | from airflow.models import BaseOperator from airflow.utils import apply_defaults class DummyOperator(BaseOperator): """ Operator that does literally nothing. It can be used to group tasks in a DAG. """ template_fields = tuple() ui_color = '#e8f7e4' @apply_defaults def __init__(self, *args, **kwargs): super(DummyOperator, self).__init__(*args, **kwargs) def execute(self, context): pass